USE AdventureWorks2014;
GO

/* Create a Select Query that shows Total Sales By SalesPerson */
SELECT sp.BusinessEntityID
      ,p.FirstName
	  ,p.LastName
	  ,SUM (sod.OrderQty*sod.UnitPrice) as TotalSales
FROM Sales.SalesPerson AS sp
     INNER JOIN Person.Person AS p
	 ON sp.BusinessEntityID=p.BusinessEntityID
	 INNER JOIN Sales.SalesOrderHeader AS soh
	 ON p.BusinessEntityID =SalesPersonID
	 INNER JOIN Sales.SalesOrderDetail as sod
	 ON soh.SalesOrderID=sod.SalesOrderID
GROUP BY sp.businessentityid,p.firstname,p.lastname;
GO

/* Create a view for TotalSales by SalesPerson */
CREATE VIEW Sales.vSalesBySalesPerson
WITH SCHEMABINDING
--WITH VIEW_METADATA
--WITH ENCRYPTION
AS 
  SELECT sp.BusinessEntityID
		,p.FirstName
		,p.LastName
		,SUM(sod.OrderQty*sod.UnitPrice) as TotalSales
  FROM Sales.SalesPerson AS sp
     INNER JOIN Person.Person AS p
	 ON sp.BusinessEntityID=p.BusinessEntityID
	 INNER JOIN Sales.SalesOrderHeader AS soh
	 ON p.BusinessEntityID =SalesPersonID
	 INNER JOIN Sales.SalesOrderDetail as sod
	 ON soh.SalesOrderID=sod.SalesOrderID
  GROUP BY sp.BusinessEntityID,p.FirstName,p.LastName;
GO

--Add TWO Columns to the View with ALTER VIEW--
ALTER VIEW Sales.vSalesBySalesPerson
WITH SCHEMABINDING
AS 
  SELECT sp.BusinessEntityID
		,p.FirstName
		,p.LastName
		,st.Name as Territory
		,SUM (sod.OrderQty*sod.UnitPrice) as TotalSales
		--,YEAR (OrderDate)
  FROM Sales.SalesPerson AS sp
     INNER JOIN Person.Person AS p
	 ON sp.BusinessEntityID=p.BusinessEntityID
	 INNER JOIN Sales.SalesOrderHeader AS soh
	 ON p.BusinessEntityID =SalesPersonID
	 INNER JOIN Sales.SalesOrderDetail as sod
	 ON soh.SalesOrderID=sod.SalesOrderID
	 INNER JOIN Sales.SalesTerritory as st
	 ON soh.TerritoryID=st.TerritoryID
  GROUP BY sp.BusinessEntityID,p.FirstName,p.LastName,st.Name,YEAR(OrderDate);
GO
--Query the altered view
SELECT *
FROM Sales.vSalesBySalesPerson
ORDER BY Territory;
GO
--Drop the View
IF OBJECT_ID('Sales.vSalesBySalesPerson', 'V') IS NOT NULL
    DROP VIEW Sales.vSalesBySalesPerson;
GO
/* Create an Inline Table-Valued Function for TotalSales by SalesPerson */
CREATE FUNCTION Sales.fn_OrderTotalsByYear
--(@top AS INT)
RETURNS TABLE  --variable name and format 
AS
RETURN         --inserts rows into variable above
(
 SELECT /*TOP (@top) SUM(sod.OrderQty*sod.UnitPrice) AS TotalSales */
        sp.BusinessEntityID
		,p.FirstName
		,p.LastName
 FROM Sales.SalesPerson AS sp
     INNER JOIN Person.Person AS p
	 ON sp.BusinessEntityID=p.BusinessEntityID
	 INNER JOIN Sales.SalesOrderHeader AS soh
	 ON p.BusinessEntityID =SalesPersonID
	 INNER JOIN Sales.SalesOrderDetail as sod
	 ON soh.SalesOrderID=sod.SalesOrderID
  GROUP BY sp.BusinessEntityID,p.FirstName,p.LastName
);
GO
--verify you can use function as a table.
SELECT *
FROM Sales.fn_OrderTotalsByYear();

