USE AdventureWorks2014;
GO
--Create a Query to give you results for a view--
SELECT  CUST.CustomerID ,
        SOH.SalesOrderID ,
        SOD.ProductID ,
        SUM(SOD.OrderQty) AS TotalOrderQty ,
        SUM(LineTotal) AS TotalValue
FROM    Sales.SalesOrderHeader SOH
        INNER JOIN Sales.SalesOrderDetail SOD
               ON SOH.SalesOrderID = SOD.SalesOrderID
        INNER JOIN Production.Product PROD ON PROD.ProductID = SOD.ProductID
        INNER JOIN Sales.Customer CUST ON SOH.CustomerID = CUST.CustomerID
        INNER JOIN Person.Person PER ON PER.BusinessEntityID = CUST.PersonID
GROUP BY CUST.CustomerID ,
        SOH.SalesOrderID ,
        SOD.ProductID; 

--Create a View--
CREATE VIEW Sales.vSalesSummaryCustomerProduct
WITH SCHEMABINDING
AS
    SELECT  CUST.CustomerID ,
            SOH.SalesOrderID ,
            SOD.ProductID ,
            SUM(SOD.OrderQty) AS TotalOrderQty ,
            SUM(LineTotal) AS TotalValue ,
            COUNT_BIG(*) AS CountLines
    FROM    Sales.SalesOrderHeader SOH
            INNER JOIN Sales.SalesOrderDetail SOD
                   ON SOH.SalesOrderID = SOD.SalesOrderID
            INNER JOIN Production.Product PROD
                   ON PROD.ProductID = SOD.ProductID
            INNER JOIN Sales.Customer CUST
                   ON SOH.CustomerID = CUST.CustomerID
            INNER JOIN Person.Person PER
                   ON PER.BusinessEntityID = CUST.PersonID
    GROUP BY CUST.CustomerID ,
            SOH.SalesOrderID ,
            SOD.ProductID; 
GO

--Index a view--
CREATE UNIQUE CLUSTERED INDEX CX_vSalesSummaryCustomerProduct
  ON Sales.vSalesSummaryCustomerProduct(CustomerID, SalesOrderID, ProductID); 
GO
--Verify a view--
SELECT  CustomerID ,
        COUNT(SalesOrderID) AS OrderCount ,
        SUM(TotalValue) AS OrderValue
FROM    Sales.vSalesSummaryCustomerProduct WITH ( NOEXPAND )
GROUP BY CustomerID

DROP VIEW Sales.vSalesSummaryCustomerProduct;