USE AdventureWorks2012;
GO
/* Selects data from one table and inserts into an existing table. 
Remaining data in existing table is unaffected.*/

INSERT INTO table (destination)
SELECT * FROM table (source)

/*Creates a new table and loads it with data from a SELECT statement */

SELECT c.FirstName
      ,c.LastName
	  ,e.JobTitle
	  ,a.AddressLine1
	  ,a.City
	  ,sp.Name AS [State/Province]
	  ,a.PostalCode
INTO dbo.EmployeeAddresses
FROM Person.Person AS c
    JOIN HumanResources.Employee AS e 
    ON e.BusinessEntityID = c.BusinessEntityID
    JOIN Person.BusinessEntityAddress AS bea
    ON e.BusinessEntityID = bea.BusinessEntityID
    JOIN Person.Address AS a
    ON bea.AddressID = a.AddressID
    JOIN Person.StateProvince as sp 
    ON sp.StateProvinceID = a.StateProvinceID;
GO

SELECT *
FROM dbo.EmployeeAddresses;
--Insert a single row using VALUES clause--

INSERT INTO dbo.EmployeeAddresses
VALUES ('Ronnie','Wong','IT','6933 NW 4th Blvd','Gainesville', 'FL', '32607');
GO

--Creates a table, inserts rows using VALUES.--
IF OBJECT_ID (N'dbo.Departments', N'U') IS NOT NULL 
    DROP TABLE dbo.Departments;
GO
CREATE TABLE dbo.Departments (DeptID tinyint NOT NULL PRIMARY KEY
            ,DeptName nvarchar(30)
			,Manager nvarchar(50));
GO
INSERT INTO dbo.Departments 
    VALUES (1, 'Human Resources', 'Byers')
	      ,(2, 'Sales', 'Rodrick')
		  ,(3, 'Finance', 'Lowrie')
		  ,(4, 'Purchasing', 'Bryan')
		  ,(5, 'Manufacturing', 'Pezet');

SELECT *
FROM dbo.Departments;

/* Add values into a table from one or more other tables or views. 
Use SELECT subquery in the INSERT statement.  
The SELECT subquery also lets more than one row be inserted 
at the same time. */

USE AdventureWorks2012;
GO
CREATE TABLE MySalesReason (SalesReasonID int NOT NULL
            ,Name nvarchar(50)
			,ModifiedDate datetime);
GO
INSERT INTO MySalesReason
     SELECT SalesReasonID
	       ,Name
	  	   ,ModifiedDate
     FROM Sales.SalesReason
     WHERE ReasonType = N'Marketing';
GO
SELECT SalesReasonID, Name, ModifiedDate 
FROM MySalesReason;
GO

/* Creates a new table, inserts data for top N. 
Use SELECT to verify contents of new table. */
 
USE AdventureWorks2012;
GO
IF OBJECT_ID (N'HumanResources.NewEmployee', N'U') IS NOT NULL
   DROP TABLE HumanResources.NewEmployee;
GO
CREATE TABLE HumanResources.NewEmployee
(
     BusinessEntityID int NOT NULL
	,LastName nvarchar(50) NOT NULL
	,FirstName nvarchar(50) NOT NULL
	,PhoneNumber Phone NULL
	,AddressLine1 nvarchar(60) NOT NULL
	,City nvarchar(30) NOT NULL
	,State nchar(3) NOT NULL
	,PostalCode nvarchar(15) NOT NULL
	,CurrentFlag Flag
);
GO
--Insert 10 random rows into the table NewEmployee.**
	INSERT TOP (10) INTO HumanResources.NewEmployee
    SELECT
       e.BusinessEntityID, c.LastName, c.FirstName, pp.PhoneNumber,
       a.AddressLine1, a.City, sp.StateProvinceCode, 
       a.PostalCode, e.CurrentFlag
    FROM HumanResources.Employee e
        INNER JOIN Person.BusinessEntityAddress AS bea
        ON e.BusinessEntityID = bea.BusinessEntityID
        INNER JOIN Person.Address AS a
        ON bea.AddressID = a.AddressID
        INNER JOIN Person.PersonPhone AS pp
        ON e.BusinessEntityID = pp.BusinessEntityID
        INNER JOIN Person.StateProvince AS sp
        ON a.StateProvinceID = sp.StateProvinceID
        INNER JOIN Person.Person as c
        ON e.BusinessEntityID = c.BusinessEntityID;
GO

SELECT  BusinessEntityID, LastName, FirstName, PhoneNumber,
        AddressLine1, City, State, PostalCode, CurrentFlag
FROM HumanResources.NewEmployee;
GO