USE AdventureWorks2014;
GO
/* Query to find out how I can categorize each of my customers
into categories based on TotalSales */

--TotalSales by each CustomerID
SELECT   soh.CustomerID, 
         SUM (sod.UnitPrice * sod.OrderQty) AS TotalSales 
FROM     Sales.SalesOrderDetail AS sod 
         INNER JOIN Sales.SalesOrderHeader AS soh 
           ON sod.SalesOrderID = soh.SalesOrderID 
GROUP BY soh.CustomerID
ORDER BY TotalSales DESC;
--returns 19119 rows

-- Query that returns all Customers to each group
SELECT   soh.CustomerID
		,SUM (sod.UnitPrice * sod.OrderQty) AS TotalSales
		,CASE
		     WHEN SUM (sod.UnitPrice * sod.OrderQty)
			      BETWEEN 0 AND 5000 THEN 'Micro'
			 WHEN SUM (sod.UnitPrice * sod.OrderQty)
			      BETWEEN 5001 AND 10000 THEN 'Mini'
			 WHEN SUM (sod.UnitPrice * sod.OrderQty)
			      BETWEEN 10001 AND 15000 THEN 'Medium'
             WHEN SUM (sod.UnitPrice * sod.OrderQty)
			      BETWEEN 15001 AND 20000 THEN 'Mega'
			 WHEN SUM (sod.UnitPrice * sod.OrderQty)
			      > 20000 THEN 'Mighty'
		  END AS OrderGroup
FROM Sales.SalesOrderDetail AS sod 
     INNER JOIN Sales.SalesOrderHeader AS soh 
     ON sod.SalesOrderID = soh.SalesOrderID 
GROUP BY soh.CustomerID
ORDER BY TotalSales DESC;
GO

/* Use a Derived Table, to find out HOW MANY customers 
are in each OrderGroup */
SELECT	og.OrderGroup
		,COUNT(og.OrderGroup) as NumberOf
FROM	(SELECT soh.CustomerID
		       ,SUM (sod.UnitPrice * sod.OrderQty) AS TotalSales
		       ,CASE
		            WHEN SUM (sod.UnitPrice * sod.OrderQty)
			        BETWEEN 0 AND 5000 THEN 'Micro'
			        WHEN SUM (sod.UnitPrice * sod.OrderQty)
			        BETWEEN 5001 AND 10000 THEN 'Mini'
			        WHEN SUM (sod.UnitPrice * sod.OrderQty)
			        BETWEEN 10001 AND 15000 THEN 'Medium'
                    WHEN SUM (sod.UnitPrice * sod.OrderQty)
			        BETWEEN 15001 AND 20000 THEN 'Mega'
			        WHEN SUM (sod.UnitPrice * sod.OrderQty)
			        > 20000 THEN 'Mighty'
				END AS OrderGroup
			FROM Sales.SalesOrderDetail AS sod 
			INNER JOIN Sales.SalesOrderHeader AS soh 
			ON sod.SalesOrderID = soh.SalesOrderID 
			GROUP BY soh.CustomerID) AS og
GROUP BY og.OrderGroup;
GO