IF OBJECT_ID('spCustomerOrders', 'P') IS NOT NULL
    DROP PROC spCustomerOrders;

/* Create a select query with variables for scalar output*/

DECLARE
		@custid AS INT
	   ,@OrderDateFrom AS DateTime 
	   ,@OrderDateTo AS DateTime 
    SET @custid = 29875;
    SET @orderdatefrom = '2011-04-01';
    SET @orderdateto = '2011-07-01';
SELECT sod.SalesOrderID
	  ,soh.CustomerID
      ,v.BusinessEntityID
	  ,soh.OrderDate
	  ,soh.DueDate
	  ,soh.ShipDate
FROM Sales.SalesOrderHeader AS soh
     INNER JOIN 
	 Sales.SalesOrderDetail AS sod
	 ON soh.SalesOrderID=sod.SalesOrderID
	 INNER JOIN Production.Product AS prod
	 ON sod.ProductID=prod.ProductID
	 INNER JOIN Production.ProductSubcategory AS psub
	 ON prod.ProductSubcategoryID=psub.ProductSubcategoryID
	 INNER JOIN Production.ProductCategory AS pcat
	 ON psub.ProductCategoryID=pcat.ProductCategoryID
	 INNER JOIN Purchasing.ProductVendor AS pv
	 ON prod.ProductID=pv.ProductID
	 INNER JOIN Purchasing.Vendor AS v
	 ON pv.BusinessEntityID=v.BusinessEntityID
     WHERE OrderDate > @OrderDatefrom
		   AND OrderDate < @OrderDateto
		   AND CustomerID = 29875
GO


IF OBJECT_ID('spGetCustomerOrders', 'P') IS NOT NULL
    DROP PROC spGetCustomerOrders;
GO
--Stored Procedure to get a range of information.
CREATE PROC spCustomerOrders
	       (@custid AS INT
		   ,@OrderDateFrom AS DateTime = '20010101'
		   ,@OrderDateTo AS DateTime = '20161231'
		   ,@numrows AS INT = 0 OUTPUT
		   )
AS
	BEGIN
	     SET NOCOUNT ON;
		 SELECT sod.SalesOrderID
		       ,soh.CustomerID
			   ,v.BusinessEntityID
			   ,soh.OrderDate
			   ,soh.DueDate
			   ,soh.ShipDate
		 FROM Sales.SalesOrderHeader AS soh
              INNER JOIN 
			  Sales.SalesOrderDetail AS sod
			  ON soh.SalesOrderID=sod.SalesOrderID
			  INNER JOIN Production.Product AS prod
			  ON sod.ProductID=prod.ProductID
			  INNER JOIN Production.ProductSubcategory AS psub
			  ON prod.ProductSubcategoryID=psub.ProductSubcategoryID
			  INNER JOIN Production.ProductCategory AS pcat
			  ON psub.ProductCategoryID=pcat.ProductCategoryID
			  INNER JOIN Purchasing.ProductVendor AS pv
			  ON prod.ProductID=pv.ProductID
			  INNER JOIN Purchasing.Vendor AS v
			  ON pv.BusinessEntityID=v.BusinessEntityID
          WHERE OrderDate > @OrderDatefrom
			    AND OrderDate < @OrderDateto
	SET @numrows = @@ROWCOUNT;
    RETURN;
END

--Run the Stored Procedure with Filters
DECLARE @rowsreturned AS INT;
EXEC spCustomerOrders
  @custid   = '29875',
  @orderdatefrom = '20110401',
  @orderdateto  = '20110701',
  @numrows = @rowsreturned OUTPUT;
SELECT @rowsreturned AS "Rows Returned";
GO