USE AdventureWorks2012;
GO

CREATE TABLE dbo.SalesOrders
            (
			 SalesOrderID INT NOT NULL IDENTITY(1,1)
			 CONSTRAINT PK_SalesOrders_SalesOrderID PRIMARY KEY,
			 CustomerID INT NOT NULL,
			 BusinessEntityID INT NOT NULL,
			 OrderDate DATE NOT NULL
			 CONSTRAINT DF_SalesOrder_OrderDate DEFAULT (CAST(SysDateTime()AS Date)),
			 ShipCountry NVARCHAR(15) NOT NULL,
			 Freight MONEY NOT NULL,
			);

--INSERT into dbo.SalesOrder
INSERT INTO dbo.SalesOrders 
   (CustomerID,BusinessEntityID,OrderDate,ShipCountry,Freight)
   Values (2,19,'20160509','USA', 35.00);

INSERT INTO dbo.SalesOrders
   (CustomerID,BusinessEntityID,OrderDate,ShipCountry,Freight)
   Values
         (1, 11,'20120622','USA',35.00),
		 (4, 13,'20120702','USA',14.00),
		 (6, 15,'20130720','USA',74.00); 

--Insert rows that exists in another table
SET IDENTITY_INSERT dbo.SalesOrders ON;
INSERT INTO dbo.SalesOrders
           (SalesOrderID
		   ,CustomerID
		   ,BusinessEntityID
		   ,OrderDate
		   ,ShipCountry
		   ,Freight)
SELECT soh.SalesOrderID
      ,soh.CustomerID
	  ,sp.BusinessEntityID
	  ,soh.OrderDate
	  ,cr.Name as ShipCountry
	  ,soh.Freight
FROM Sales.SalesOrderHeader AS soh
     INNER JOIN Sales.SalesTerritory AS st
	 ON soh.TerritoryID = st.TerritoryID
	 INNER JOIN Person.CountryRegion AS cr
	 ON st.CountryRegionCode = cr.CountryRegionCode
	 INNER JOIN Sales.SalesPerson as sp
	 ON st.TerritoryID=sp.TerritoryID
--WHERE cr.Name = 'Germany';

SET IDENTITY_INSERT dbo.SalesOrders OFF;

--Create a stored procedure that can insert records into a target table.
IF OBJECT_ID('spOrdersForCountry', 'P') IS NOT NULL
  DROP PROC spOrdersForCountry;
GO
CREATE PROC spOrdersForCountry
  @country AS NVARCHAR(15)
AS
SELECT SalesOrderID
      ,CustomerID
	  ,businessentityID
	  ,orderdate
	  ,cr.Name as ShipCountry
	  ,freight
FROM Sales.SalesOrderHeader AS soh
     INNER JOIN Sales.SalesTerritory AS st
	 ON soh.TerritoryID = st.TerritoryID
	 INNER JOIN Person.CountryRegion AS cr
	 ON st.CountryRegionCode = cr.CountryRegionCode
	 INNER JOIN Sales.SalesPerson as sp
	 ON st.TerritoryID=sp.TerritoryID
WHERE cr.Name = @country;
GO

SET IDENTITY_INSERT dbo.SalesOrders ON;
INSERT INTO dbo.SalesOrders(SalesOrderID
                           ,CustomerID
						   ,BusinessEntityID
						   ,orderdate
						   ,shipcountry
						   ,freight)
EXEC spOrdersforCountry
    @country = 'Canada';
SET IDENTITY_INSERT dbo.salesorders OFF;

select *
from dbo.SalesOrders

DROP TABLE dbo.SalesOrders

--Create table and insert data using SELECT INTO
IF OBJECT_ID('dbo.SalesOrders', 'U') IS NOT NULL DROP TABLE dbo.SalesOrders;

SELECT soh.SalesOrderID
      ,soh.CustomerID
	  ,orderdate
	  ,cr.Name AS shipcountry
	  ,soh.Freight
--INTO dbo.SalesOrders
FROM Sales.SalesOrderHeader AS soh
     INNER JOIN Sales.SalesTerritory AS st
	 ON soh.TerritoryID = st.TerritoryID
	 INNER JOIN Person.CountryRegion AS cr
	 ON st.CountryRegionCode = cr.CountryRegionCode
	 INNER JOIN Sales.SalesPerson as sp
	 ON st.TerritoryID=sp.TerritoryID
WHERE cr.Name ='Canada';
