--TRY/CATCH - Error is handled and transaction is rolled back but error is not reported.
BEGIN TRY
BEGIN TRAN;
    SET IDENTITY_INSERT Production.Product ON;
    INSERT INTO Production.Product
	           (productid, name, color,ProductSubcategoryID
			   ,ListPrice, ProductLine
			   )
        VALUES(1, 'Test1: Ok ProductSubcategoryid', 1, 1, 18.00, 0);
    INSERT INTO Production.Product
	            (productid, name, color,ProductSubcategoryID
				,ListPrice, ProductLine)
        VALUES(101, 'Test2: Bad ProductSubcategoryid', 1, 10, 18.00, 0);
    SET IDENTITY_INSERT Production.Product OFF;
COMMIT TRAN;
END TRY
BEGIN CATCH
    IF ERROR_NUMBER() = 2627 -- Duplicate key violation
        BEGIN
            PRINT 'Primary Key violation';
        END
    ELSE IF ERROR_NUMBER() = 547 -- Constraint violations
        BEGIN
            PRINT 'Constraint violation';
        END
    ELSE 
	    BEGIN
            PRINT 'Unhandled error';
        END;
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;
END CATCH;

-- Use Variables to capture error and use RAISERROR
SET NOCOUNT ON;
DECLARE @error_number AS INT
       ,@error_message AS NVARCHAR (500)
	   ,@error_severity AS INT;
BEGIN TRY
BEGIN TRAN;
    SET IDENTITY_INSERT Production.Product ON;
    INSERT INTO Production.Product
	           (productid, name, color,ProductSubcategoryID
			   ,ListPrice, ProductLine
			   )
        VALUES(1, 'Test1: Ok ProductSubcategoryid', 1, 1, 18.00, 0);
    INSERT INTO Production.Product
	            (productid, name, color,ProductSubcategoryID
				,ListPrice, ProductLine)
        VALUES(101, 'Test2: Bad ProductSubcategoryid', 1, 10, 18.00, 0);
    SET IDENTITY_INSERT Production.Product OFF;
COMMIT TRAN;
END TRY
BEGIN CATCH
            SELECT XACT_STATE() as 'XACT_STATE' 
	        -- 1 open xact (commit or rollback); 0 no open xact; -1 xact only rolled back
		   ,@@TRANCOUNT as '@@TRANCOUNT';
            SELECT @error_number = ERROR_NUMBER()
		   ,@error_message = ERROR_MESSAGE()
		   ,@error_severity = ERROR_SEVERITY();
            RAISERROR (@error_message, @error_severity, 1); --re-raises the error with custom number
            IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;
END CATCH;

-- USE THROW to report Original Error Message back to the client.
BEGIN TRY
BEGIN TRAN;
    SET IDENTITY_INSERT Production.Product ON;
    INSERT INTO Production.Product
	           (productid, name, color,ProductSubcategoryID
			   ,ListPrice, ProductLine
			   )
        VALUES(1, 'Test1: OK ProductSubcategoryid', 1, 1, 18.00, 0);
    INSERT INTO Production.Product
	            (productid, name, color,ProductSubcategoryID
				,ListPrice, ProductLine)
        VALUES(101, 'Test2: Bad ProductSubcategoryid', 1, 10, 18.00, 0);
    SET IDENTITY_INSERT Production.Product OFF;
COMMIT TRAN;
END TRY
BEGIN CATCH
            SELECT XACT_STATE() as 'XACT_STATE'
		   ,@@TRANCOUNT as '@@TRANCOUNT';
            IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION;
            THROW; --This must be the last statement in CATCH
END CATCH;
GO
   SELECT XACT_STATE() as 'XACT_STATE'
         ,@@TRANCOUNT as '@@TRANCOUNT';