###Querying Microsoft SQL Server 2014 - Exam 70-461
{FileName}microsoft-sql70461-1-2-create_and_alter_views-MMDDYY
{EpisodeName}Create and alter views
{ShowName}Querying Microsoft SQL Server 2014
{Description}
*In December 2015, this exam was evaluated for applicability to both SQL Server 2012 and SQL Server 2014. It was determined that no updates to exam objectives were required.*

###1.2 Create and alter views
------------------------------------------------------------

* Design and implement inline functions.
	+ Inline Table-Valued Function
		- User defined function that returns more than a single value but an entire table.
		- Used as an alternative to a view.  Used instead of table or view can be used in SQL querying.
		- Can also be a replacement for stored procedures that return result set.
		- Resulting table is used in FROM clause
		- the select statement in the function is not meant to return a direct result to user.
		- Characteristics:
			+ Stored as object in database
			+ Returns a virtual table
			+ Reusable
			+ Can accept input parameters to pass into the SELECT statement.
	+ Example
```
/* Create an Inline Table-Valued Function for TotalSales by SalesPerson */
CREATE FUNCTION Sales.fn_OrderTotalsByYear
--(@top AS INT)
RETURNS TABLE  --variable name and format 
AS
RETURN         --inserts rows into variable above
(
 SELECT /*TOP (@top) SUM(sod.OrderQty*sod.UnitPrice) AS TotalSales */
        sp.BusinessEntityID
		,p.FirstName
		,p.LastName
 FROM Sales.SalesPerson AS sp
     INNER JOIN Person.Person AS p
	 ON sp.BusinessEntityID=p.BusinessEntityID
	 INNER JOIN Sales.SalesOrderHeader AS soh
	 ON p.BusinessEntityID =SalesPersonID
	 INNER JOIN Sales.SalesOrderDetail as sod
	 ON soh.SalesOrderID=sod.SalesOrderID
  GROUP BY sp.BusinessEntityID,p.FirstName,p.LastName
);
GO
``` 
```
--Verify the function is working with and without parameters.
SELECT *
FROM Sales.fn_OrderTotalsByYear();
```
Remove the /* and */ from select to add parameter; also when verifying put the number 5 within the ( )
* Create indexed views
``` 
USE AdventureWorks2014;
GO
--Set Stats I/0 to ON--
SET STATISTICS IO ON;
-- Aggregate query with a join
SELECT st.Name as Territory
      ,SUM(soh.SubTotal) AS SalesTotals`
FROM Sales.SalesOrderHeader AS soh
   	 INNER JOIN Sales.SalesTerritory as st
	 ON soh.TerritoryID=st.TerritoryID
GROUP BY st.Name;
GO
``` 
```
--Set Stats I/0 to ON--
SET STATISTICS IO off;
``` 
```
--Create a View
CREATE VIEW Sales.vQuantityByTerritory
WITH SCHEMABINDING
AS
SELECT st.Name
      ,SUM(soh.SubTotal) AS SalesTotals
	  ,COUNT_BIG(*) AS TotalRows
FROM Sales.SalesOrderHeader AS soh
	 INNER JOIN Sales.SalesTerritory as st
	 ON soh.TerritoryID=st.TerritoryID
GROUP BY st.Name;
GO
``` 
```
--Index the view
CREATE UNIQUE CLUSTERED INDEX idx_cl_territory
ON Sales.vQuantityByTerritory(Name);
GO
``` 
```
SELECT Name as Territory
      ,SalesTotals
FROM sales.vQuantityByTerritory WITH (NOEXPAND)
--GROUP BY st.Name;
GO
``` 
```
--Turn off Stats and drop view
SET STATISTICS IO OFF;
DROP VIEW Sales.vQuantityByTerritory;
```

* Ensure code non regression by keeping consistent signature for procedure, views and function (interfaces);
	+ Try int make sure that you do not break functionality to SQL Server 2014 database.
	+ Changes to Database through Stored Procedure and Access to Stored Procedure.
	+ `WITH_ENCRYPTION`
		- Prevents view from being published when SQL Servers replicate
	+ `WITH CHECK OPTION`
		- Remember that you can modify table values from a view.
		- When using the WHERE clause in the view to filter, you can still modify the table where the results will not show your filtered result anymore even outside of the where clause.
		- This option prevents that from happening that if you're using a view to modify the database, it limits the modifications to the filtered options in the where statement.
	+ Adding a Signature to the code to prevent unauthorized changes to your code as well.
	
