Querying Microsoft SQL Server 2014 - Exam 70-461
============================================================
{FileName}microsoft-sql70461-1-3-create_and_modify_constraints-MMDDYY
{EpisodeName}Create & Modify Constraints
{ShowName}Querying Microsoft SQL Server 2014
{Description}
*In December 2015, this exam was evaluated for applicability to both SQL Server 2012 and SQL Server 2014. It was determined that no updates to exam objectives were required.*
1.3 Create and modify constraints (simple statements)
------------------------------------------------------------
* Create constraints on tables
	+ Best way to enforce data integrity
	+ `CREATE TABLE`
	+ `ALTER TABLE` 

* Primary key constraints
	+ The column or columns cannot allow NULL. If the column or columns allow NULL, the constraint command will fail.
	+ Any data already in the table must have unique values in the primary key column or columns. If there are any duplicates, the ALTER TABLE statement will fail.
	+ There can be only one primary key constraint at a time in a table. If you try to create two primary key constraints on the same table, the command will fail.
	+ the PK distinguishes every row by providing a unique identifier.
	+ SQL Server will create a unique index on PK column
	+ Example for Primary Key
``` 
USE AdventureWorks2012;
GO
--Define new table--
CREATE TABLE dbo.Categories
			(
			  CategoryID INT NOT NULL IDENTITY
			 ,CategoryName NVARCHAR(15)  NOT NULL
			 ,Description NVARCHAR(200) NOT NULL
			);
GO
``` 
```
--Use Alter Table to ADD a constraint--
ALTER TABLE dbo.Categories
     ADD PK_Cat PRIMARY KEY (CategoryID);
```
``` 
--Query for all PK in database
SELECT *
FROM sys.key_constraints
WHERE type = 'PK';
```

* Foreign Key
		- The column or set of columns from each table must have exactly the same data types and collation (if they have a string data type).
		- As mentioned earlier, the columns of the referenced table must have a unique index created on them, either implicitly with a primary key or a unique constraint, or explicitly by creating the index.
		- You can also create foreign key constraints on computed columns.
		- Example for Foreign Key
``` 
CREATE TABLE dbo.Products
(
  ProductID    INT          NOT NULL IDENTITY
 ,ProductName  NVARCHAR(50) NOT NULL
 ,SupplierID   INT NOT NULL
 ,CategoryID   INT NOT NULL
 ,UnitPrice    MONEY NOT NULL
 ,discontinued BIT NOT NULL
);
``` 
```
ALTER TABLE Production.Products  WITH CHECK
    ADD  CONSTRAINT FK_Products_Categories FOREIGN KEY(categoryid)
    REFERENCES dbo.Categories (CategoryID)
```

* Unique Constraints
	+ When you still want to make sure that unique values even though not a primary key. e.g. CategoryName
``` 
ALTER TABLE Production.Categories
     ADD CONSTRAINT UC_Categories UNIQUE (categoryname);
GO
```
```
--query to see the Unique Constraint--
SELECT *
FROM sys.key_constraints
WHERE type = 'UQ';
```

* Default Constraints: Default constraints are most useful when you have a column in a table that does not allow NULL, but you don't want to prevent an INSERT from succeeding if it does not specify a value for the column. 
* Unique constraints
 	+ Similar to PK constraint
	+ Can be NULL but only ONE ROW can be NULL
	+ Can be created on computed column (PK and Unique)
	+ Great when you want to supply a default values
	+ Example
``` 
CREATE TABLE dbo.Products1
(
  ProductID    INT          NOT NULL IDENTITY
 ,ProductName  NVARCHAR(50) NOT NULL
 ,SupplierID   INT NOT NULL
 ,CategoryID   INT NOT NULL
 ,UnitPrice    MONEY NOT NULL
 ,CONSTRAINT DFT_Products_UnitPrice DEFAULT(0)
 ,discontinued BIT NOT NULL
 ,CONSTRAINT DFT_Products_discontinued DEFAULT(0)
);
``` 
``` 
SELECT *
FROM sys.default_constraints
WHERE parent_object_id = OBJECT_ID('dbo.Products1');
```