###Querying Microsoft SQL Server 2012 - Exam 70-461
{FileName}microsoft-sql70461-2-1-query_data-using_select-MMDDYY
{EpisodeName}
{ShowName}Querying Microsoft SQL Server 2012
{Description}
*In December 2015, this exam was evaluated for applicability to both SQL Server 2012 and SQL Server 2014. It was determined that no updates to exam objectives were required.*
####2.0 Work with data (25–30%)
* 2.1 Query data by using SELECT statements
	+ Use and understand different *data access technologies*
		- What are the different Data Access Technologies?
		- [Microsoft SQL 2012 Feature Pack](https://www.microsoft.com/en-us/download/confirmation.aspx?id=29065)
		- [Microsoft SQL 2014 Feature Pack](https://www.microsoft.com/en-us/download/details.aspx?id=42295)
			+ SQL Server Native Client (SNAC)
				- API for OLE DB and ODBC
				- create new applications
				- enhance application.
				- In SQL 2014, OLE DB will not be included
			+ Microsoft ODBC Driver for SQL Server
				- Provides ODBC drivers for Windows, RedHat and SUSE
			+ ADO.NET
				- targeted at loosely coupled, n-tier, internet-based applications that support disconnected access to data.
				- Core component of Microsoft .NET Framework.
				- Provides .NET-managed providers for connected access
				- provides datasets that read and write in XML for disconnected management and user interaction.
			+ Microsoft JDBC Driver for SQL Server
				- Java Database Connectivity 4.0 compliant driver
				- Can be installed on Windows or UNIX
			+ Microsoft Drivers for PHP for SQL Server
				- PHP5 extension
					+ procedural interface
					+ object-oriented interace
			+ Microsoft Driver for Node.js for SQL Server
				- allows Node.js applications on Windows and Microsoft Azure.
				- access to both Microsoft SQL and Azure SQL Databases.
			+ Microsoft/Windows Data Access Components (MDAC/WDAC)
				- Developers can connect to and use data from Relational and non-Relational data sources.
		- Why do I need to know it?
			+ How to get access to the different applications.
		- How can I show it?
			+ Demonstrate in Microsoft Management Studio
	+ Given a table with constraints, determine which statement set would load a table.
		- **Selects data from one table and inserts into an existing table. Remaining data in existing table is unaffected.**
``` 
INSERT INTO table (destination)
SELECT * FROM table (source)
```
		- **Creates a new table and loads it with data from a SELECT statement or create a new table from selected data in a linked server.**
``` 
USE AdventureWorks2012;
GO
SELECT c.FirstName, c.LastName, e.JobTitle, a.AddressLine1, a.City, 
    sp.Name AS [State/Province], a.PostalCode
INTO dbo.EmployeeAddresses
FROM Person.Person AS c
    JOIN HumanResources.Employee AS e 
    ON e.BusinessEntityID = c.BusinessEntityID
    JOIN Person.BusinessEntityAddress AS bea
    ON e.BusinessEntityID = bea.BusinessEntityID
    JOIN Person.Address AS a
    ON bea.AddressID = a.AddressID
    JOIN Person.StateProvince as sp 
    ON sp.StateProvinceID = a.StateProvinceID;
GO
```
		- **Insert a single row using VALUES clause**
```
USE AdventureWorks2012;
GO
INSERT INTO dbo.EmployeeAddresses
VALUES ('Ronnie','Wong','IT','6933 NW 4th Blvd','Gainesville', 'FL', '32607');
GO
```
		- **Creates a table, inserts rows using VALUES**.
``` 
USE AdventureWorks2012;
GO
IF OBJECT_ID (N'dbo.Departments', N'U') IS NOT NULL 
    DROP TABLE dbo.Departments;
GO
CREATE TABLE dbo.Departments (DeptID tinyint NOT NULL PRIMARY KEY, DeptName nvarchar(30), 
    Manager nvarchar(50));
GO
INSERT INTO dbo.Departments 
    VALUES (1, 'Human Resources', 'Margheim'),(2, 'Sales', 'Byham'), 
           (3, 'Finance', 'Gill'),(4, 'Purchasing', 'Barber'),
           (5, 'Manufacturing', 'Brewer');
```
		- **Add values into a table from one or more other tables or views. Use SELECT subquery in the INSERT statement.  The SELECT  subquery also lets more than one row be inserted at the same time.**
```
USE AdventureWorks2012;
GO
CREATE TABLE MySalesReason (
    SalesReasonID int NOT NULL,
    Name nvarchar(50),
    ModifiedDate datetime);
GO
INSERT INTO MySalesReason
    SELECT SalesReasonID, Name, ModifiedDate
    FROM AdventureWorks2008R2.Sales.SalesReason
    WHERE ReasonType = N'Marketing';
GO
SELECT SalesReasonID, Name, ModifiedDate 
FROM MySalesReason;
GO
```
		- **Creates a new table, inserts data for top N. Use SELECT to verify contents of new table.**
``` 
USE AdventureWorks2012;
GO
IF OBJECT_ID (N'HumanResources.NewEmployee', N'U') IS NOT NULL
    DROP TABLE HumanResources.NewEmployee;
GO
CREATE TABLE HumanResources.NewEmployee
(
    BusinessEntityID int NOT NULL,
    LastName nvarchar(50) NOT NULL,
    FirstName nvarchar(50) NOT NULL,
    PhoneNumber Phone NULL,
    AddressLine1 nvarchar(60) NOT NULL,
    City nvarchar(30) NOT NULL,
    State nchar(3) NOT NULL, 
    PostalCode nvarchar(15) NOT NULL,
    CurrentFlag Flag
);
GO
```
		- **Insert 10 random rows into the table NewEmployee.**
```language
```
	INSERT TOP (10) INTO HumanResources.NewEmployee
    SELECT
       e.BusinessEntityID, c.LastName, c.FirstName, pp.PhoneNumber,
       a.AddressLine1, a.City, sp.StateProvinceCode, 
       a.PostalCode, e.CurrentFlag
    FROM HumanResources.Employee e
        INNER JOIN Person.BusinessEntityAddress AS bea
        ON e.BusinessEntityID = bea.BusinessEntityID
        INNER JOIN Person.Address AS a
        ON bea.AddressID = a.AddressID
        INNER JOIN Person.PersonPhone AS pp
        ON e.BusinessEntityID = pp.BusinessEntityID
        INNER JOIN Person.StateProvince AS sp
        ON a.StateProvinceID = sp.StateProvinceID
        INNER JOIN Person.Person as c
        ON e.BusinessEntityID = c.BusinessEntityID;
GO
SELECT  BusinessEntityID, LastName, FirstName, PhoneNumber,
        AddressLine1, City, State, PostalCode, CurrentFlag
FROM HumanResources.NewEmployee;
GO
```
	+ Write efficient, technically complex SQL queries, including *all types of joins* versus the use of *derived tables* 
		- Queries using JOINS
			+ Query using INNER JOIN
				- result: dataset that has a matching value between the two tables.
			+ Query using LEFT JOIN
				- result: data set that has matching values between two tables and all values from left table.
		- Queries using derived tables
			+ Show query in 2 steps using JOIN
			+ Show query using derived tables
	+ Determine what code may or may not execute based on the tables provided
	+ Write and perform queries efficiently using the new (SQL 2005/8->) code items such as synonyms, and joins (except, intersect)
		- Joins 
		- Synonyms
			+ Create Synonym
			+ Drop Synonym
	+ Use the ranking function to select top(X) rows for multiple categories in a single query
		- Rank()
		- Row_Number()
		- DENSE_RANK()
		- NTILE()
	+ Implement logic which uses *dynamic SQL* and *system metadata*
		- Dynamic SQL 
			+ Where creating parameterized stored procedures is not supported
			+ Automating administrative tasks: querying metadata and backups
			+ Improving Performance
			+ Must be careful of SQL injection
			+ Two Methods:
				- EXEC Command
				- sp_executesql: input is considered operands in expressions and eliminates SQL Injection
		- System Metadata
	+ **Case** versus **isnull** versus **coalesce**
		- **CASE** 
			+ What Does CASE do?
				- Sets multiple conditions to match; provides a different answer based on the condition.
			+ When do I use it?
				- e.g. Flag when to reorder on based on stock levels.
			+ Example of using CASE:
				- Recatagorize items based on result from another column value.
		- **ISNULL**
			+ What Does ISNULL do?
				- Tests for NULL
				- replaces NULL value with another value
				- not an ANSI standard
			+ When do I use it?
				- when replacing a NULL with a value of your choosing of the same datatype.
			+ Example of using ISNULL
				- Using Same example as CASE
		- **Coalesce**
			+ What Does COALESCE do?
				- can replace NULL with another value.
				- If all arguments are null, COALESCE will return NULL.
			+ When do I use it? 
				- With more than two arguments
			+ Example of using COALESCE:
```
SELECT Name, Class, Color, ProductNumber,
COALESCE(Class, Color, ProductNumber) AS FirstNotNull
FROM Production.Product;
```