###Querying Microsoft SQL Server 2014 - Exam 70-461
{FileName}microsoft-sql70461-2-3-2-implement_subqueries_pt2-MMDDYY
{EpisodeName}Implement Subqueries Pt.2
{ShowName}Querying Microsoft SQL Server 2014
{Description}
*In December 2015, this exam was evaluated for applicability to both SQL Server 2012 and SQL Server 2014. It was determined that no updates to exam objectives were required.*
####2.3 Implement Subqueries
* Pivot and Unpivot
	+ Pivot
		- Reporting Rows as Columns
		- Helps with displaying the data differently without having to modify and create another database object.
		- Display a Basic Query
``` 
USE AdventureWorks2014;
GO
--Query to show all Category Names, Colors and Quantity
SELECT  PS.Name
	   ,P.Color
	   ,PIn.Quantity
FROM Production.Product as P
     INNER JOIN Production.ProductSubcategory PS
     ON PS.ProductSubcategoryID = P.ProductSubcategoryID
     LEFT JOIN Production.ProductInventory PIn
	 ON P.ProductID = PIn.ProductID;
GO
		- Pivot Data and Names query
``` 
--PIVOT Data Colors as columns and names and quantity as rows
SELECT *
FROM (SELECT PS.Name
            ,P.Color
			,PIn.Quantity
      FROM Production.Product P
      INNER JOIN Production.ProductSubcategory PS
      ON PS.ProductSubcategoryID = P.ProductSubcategoryID
      LEFT JOIN Production.ProductInventory PIn
      ON P.ProductID = PIn.ProductID
      ) DataTable
PIVOT
     (SUM(Quantity)
      FOR Color
      IN ( [Black],[Blue],[Grey],[Multi],[Red]
	      ,[Silver],[Silver/Black],[White],[Yellow]
          )
      ) PivotTable;
GO
```
	+ UnPivot
		- Reporting Columns as Rows from a pivot table
		- Helps when data is not normalized according to Relational Database Design
``` 
USE AdventureWorks2012;
GO
/* Select the Poorly Normalized Data */
SELECT *
FROM dbo.YearlyTotals as YearlyTotals
UNPIVOT
       ( YearlyTotals FOR Month
	          IN ( January, February,March, April
			     , May, June, July, August
				 , September, October, November, December)
	   ) as unpvt;
```
	+ APPLY operator
		- Can be used as a replacement for correlated subqueries and derived tables
			+ Correlated Subquery example
``` 
SELECT soh.SalesOrderID
      ,soh.OrderDate
      ,MaxUnitPrice = (SELECT MAX(sod.UnitPrice)
	                   FROM Sales.SalesOrderDetail sod 
		               WHERE soh.SalesOrderID = sod.SalesOrderID)
FROM Sales.SalesOrderHeader AS soh
```
			+ Derived Table example
``` 
SELECT soh.SalesOrderID
      ,soh.OrderDate
      ,sod.max_unit_price
FROM Sales.SalesOrderHeader AS soh
JOIN
    (SELECT max_unit_price = MAX(sod.UnitPrice)
           ,SalesOrderID
     FROM Sales.SalesOrderDetail AS sod
     GROUP BY sod.SalesOrderID
    ) sod
ON sod.SalesOrderID = soh.SalesOrderID
```
			+ CROSS APPLY example
``` 
SELECT soh.SalesOrderID
      ,soh.OrderDate
      ,sod.max_unit_price
FROM Sales.SalesOrderHeader AS soh
CROSS APPLY
(SELECT max_unit_price = MAX(sod.UnitPrice)
       --,SumLineTotal = SUM(sod.LineTotal)
 FROM Sales.SalesOrderDetail AS sod
 WHERE soh.SalesOrderID = sod.SalesOrderID
) AS sod
```
Replace 'Cross Apply' with 'Outer Apply' to get the equivalent of a LEFT JOIN on the derived table.
Also, remove the commented line to add more to the query without having to rerun the entire query. To do this with the correlated query or Derived Table you will rerun the entire query.
	+ Querying with CTE (Common Table Expression)
		- Similar to Derived Tables in that it is only designed to provide input to the outer join.
		- It can be referenced multiple times in the same SELECT query this is different from a Derived Table
		- Common table expression can be defined as a temporary result set or in other words it's a substitute of views in SQL Server. Common table expression is only valid in the batch of statement where it was defined and cannot be used in other sessions.
``` 
USE AdventureWorks2014;
GO
-- Define the CTE expression name and column list.
WITH Sales_CTE (SalesPersonID, SalesOrderID, SalesYear)
AS
-- Define the CTE query.
(
    SELECT SalesPersonID, SalesOrderID, YEAR(OrderDate) AS SalesYear
    FROM Sales.SalesOrderHeader
    WHERE SalesPersonID IS NOT NULL
)
-- Define the outer query referencing the CTE.
SELECT SalesPersonID, COUNT(SalesOrderID) AS TotalSales, SalesYear
FROM Sales_CTE
GROUP BY SalesYear, SalesPersonID
ORDER BY SalesPersonID, SalesYear;
GO
```
